import SQLite from "react-native-sqlite-storage";
SQLite.DEBUG(true);
SQLite.enablePromise(true);
const database_name = "Reactoffline.db";
const database_version = "1.0";
const database_displayname = "SQLite React Offline Database";
const database_size = 200000;

export default class ManageTasksCompletedOffline {
    //Create or Initialize the DB and CompletedManageTasks Table or Open DataBase
    initDB() {
        let db;
        return new Promise((resolve) => {
            // console.warn("Plugin integrity check ...");
            SQLite.echoTest()
                .then(() => {
                    // console.warn("Integrity check passed ...");
                    console.log("Opening database ...");
                    SQLite.openDatabase(
                        database_name,
                        database_version,
                        database_displayname,
                        database_size
                    )
                        .then(DB => {
                            db = DB;
                            // console.warn("Database OPEN");
                            db.executeSql('SELECT 1 FROM manageTasksCompleted LIMIT 1').then(() => {
                                // console.warn("Database is ready ... executing query ...");
                            }).catch((error) => {
                                // console.warn("Received error: ", error);
                                console.log("Database not yet ready ... populating data");
                                db.transaction((tx) => {
                                    tx.executeSql('CREATE TABLE IF NOT EXISTS manageTasksCompleted (projectitle,ideano,taskid,' +
                                        'taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,assignedon,' +
                                        'taskEndDate,completeStatus,createdon,moduleId,targettime,assignedTo,cDate,' +
                                        'extraHours,ptime)');
                                }).then(() => {
                                    console.log("Table created successfully");
                                }).catch(error => {
                                    console.log(error);
                                });
                            });
                            resolve(db);
                        })
                        .catch(error => {
                            console.warn(error);
                        });
                })
                .catch(error => {
                    console.warn("echoTest failed - plugin not functional");
                });
        });
    };

    //Close DataBase
    closeDatabase(db) {
        if (db) {
            console.log("Closing DB");
            db.close()
                .then(status => {
                    console.log("Database CLOSED");
                })
                .catch(error => {
                    this.errorCB(error);
                });
        } else {
            console.log("Database was not OPENED");
        }
    };

    //Store ManagetasksCompleted List
    addCompletedManagetasksOffline(completed) {
        //   console.warn(profile.empid)
        let array = completed
        this.deleteCompletedManageTaskOffline();
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    // console.warn(profile.empStatus)
                    array.forEach(completed => {
                        // console.warn(completed.subTaskId)
                    tx.executeSql('INSERT INTO manageTasksCompleted VALUES (?, ?, ?, ? ,?, ?, ? ,?, ?, ?, ?, ?, ? ,?, ?, ? ,?, ?, ?)', [
                        completed.projectitle,completed.ideano,completed.taskid,completed.taskStatus,completed.tasktitle,completed.taskdescription,
                        completed.assignby,completed.assigntto,completed.taskStatusDesc,completed.assignedon,completed.taskEndDate,
                        completed.completeStatus,completed.createdon,completed.moduleId,completed.targettime,completed.assignedTo,completed.cDate,
                        completed.timeLeft,completed.ptime
                    ]).then(([tx, results]) => {
                        resolve(results);
                        // console.warn("success")
                    });
                });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.warn("err" + JSON.stringify(err));
                });
            }).catch((err) => {
                console.warn("re" + err);
            });
        });
    }
    //Getting ManageTaskCompletedList Details 
    completedManageTasksListOffline() {
        console.warn("Query strated");
        return new Promise((resolve) => {
            const profile = [];
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('SELECT * FROM manageTasksCompleted', []).then(([tx, results]) => {
                        console.warn("Query completed");
                        var len = results.rows.length;
                        for (let i = 0; i < len; i++) {
                            let row = results.rows.item(i);
                            const { projectitle,ideano,taskid,taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,
                            assignedon,taskEndDate,completeStatus,createdon,moduleId,targettime,assignedTo,cDate,timeLeft,ptime} = row;
                            profile.push({
                                projectitle,ideano,taskid,taskStatus,tasktitle,taskdescription,assignby,assigntto,taskStatusDesc,assignedon,
                                taskEndDate,completeStatus,createdon,moduleId,targettime,assignedTo,cDate,timeLeft,ptime
                            });
                        }
                        // console.warn(profile)
                        resolve(profile);
                    });

                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

    //Delete CompletedManageTasks 
        deleteCompletedManageTaskOffline() {
        return new Promise((resolve) => {
            this.initDB().then((db) => {
                db.transaction((tx) => {
                    tx.executeSql('DELETE FROM manageTasksCompleted', []).then(([tx, results]) => {
                        console.warn("deleted" + results);
                        resolve(results);
                    });
                }).then((result) => {
                    this.closeDatabase(db);
                }).catch((err) => {
                    console.log(err);
                });
            }).catch((err) => {
                console.log(err);
            });
        });
    }

}