/*
FileName:UserBacklogActive.js
Version:1.0.0
Purpose:List of Backlogs of Active sprint of assigned user stories
Devloper:Mahesh, Naveen Kumar(GNK)->Offline
*/
import React, { Component } from 'react';
import { Platform, StyleSheet, Image, Text, View, Dimensions, TouchableOpacity, FlatList, LayoutAnimation, UIManager, TextInput, Alert, ToastAndroid } from 'react-native';
import { Container, Content, Item, Input, Header, Icon } from 'native-base';
import { widthPercentageToDP as wp, heightPercentageToDP as hp } from 'react-native-responsive-screen';
// import Icon from 'react-native-vector-icons/FontAwesome';
import { Collapse, CollapseHeader, CollapseBody } from "accordion-collapse-react-native";
// import DropDownPicker from 'react-native-dropdown-picker';
import ModalSelector from 'react-native-modal-selector';
import Modal from "react-native-simple-modal";
import jwt_decode from "jwt-decode";
import AsyncStorage from '@react-native-community/async-storage';
import { API } from "../WebServices/RestClient";
import NetInfo from '@react-native-community/netinfo';
import Snackbar from 'react-native-snackbar';
import Toast from 'react-native-whc-toast';
import log from '../LogFile/Log';
import { NavigationEvents } from 'react-navigation';
import moment from 'moment';

import {
  BallIndicator,
  BarIndicator,
  DotIndicator,
  MaterialIndicator,
  PacmanIndicator,
  PulseIndicator,
  SkypeIndicator,
  UIActivityIndicator
} from 'react-native-indicators';
import { SUBTASK, TITLE, DESCRIPTION, ADDMAINTASK, TARGETTIME, TASKSTATUS, ASSIGNEDON, STATUS, ASSIGNED_BY, UPDATEDON, TIMELEFT, MODIFY, UPDATESTATUS, TARGET_DATE, ASSIGNED_TO } from '../CommonComponents/Header';
import UserDatabase from '../OfflineDB/UserDatabase';
const db = new UserDatabase();

FOOTER_MAX_HEIGHT = 50
FOOTER_MIN_HEIGHT = 40

class ListItem extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      isLoading: true,
      expanded: false,
      dataSource2: [],
    }

    this.getMessages();
    if (Platform.OS === 'android') {
      UIManager.setLayoutAnimationEnabledExperimental(true);
    }

  }
  changeLayout = () => {
    LayoutAnimation.configureNext(LayoutAnimation.Presets.easeInEaseOut);
    this.setState({ expanded: !this.state.expanded });
  }


  getMessages() {
    log("Info", " getMessages(role, userToken, cropcode) is used getting task related messages");
    // const groupId = this.state.subtaskId;
    // console.warn("getmessages");
    AsyncStorage.multiGet(["cropcode", "userToken"], (err, response) => {
      const cropcode = response[0][1];
      const userToken = response[1][1];
      this.setState({ userid: userToken });
      // console.warn("userToken"+userToken)
      // console.warn("cropcode"+cropcode)

      NetInfo.fetch().then(state => {
        if (state.type == "none") {
          log("Warn", "No internet connection");
          Snackbar.show({
            title: 'No Internet Connection',
            backgroundColor: 'red',
            duration: Snackbar.LENGTH_LONG,
          });
        }
        else {
          fetch(API + "mainTaskChat.php",
            {
              method: 'POST',
              headers: {
                Accept: 'application/json',
                'Content-Type': 'application/json',
              },
              body: JSON.stringify({

                action: "getAllTaskMessages",
                corp_code: cropcode,
                // sendBy: userToken,


              })
            })
            .then((response) => response.json())
            .then((responseJson) => {
              // console.warn("Messages For chat application" + JSON.stringify(responseJson.data));

              // console.warn("Messages from users" + JSON.stringify(responseJson))
              // console.warn("Send By Name" + JSON.stringify(responseJson.data))
              if (responseJson.status === 'True') {

                // console.warn("Setted Data")



                this.setState({
                  dataSource2: responseJson.data,
                });
                // console.warn("Method data" + responseJson.data.sendBy)
              }
              else {
                // console.warn("Empty  Data")
                this.setState({
                  dataSource2: [],
                });
              }
            })
            .catch((error) => {
              console.error(error);
              log("Error", "getting task related messages error");
            });

        }
      });
    });
  }


  //Navigates to TaskChat Screen
  TaskChat(taskid, action, msgCount) {
    // console.warn("msgCount" + msgCount);
    // console.warn("taskid" + taskid);
    log("Info", "UserPendingMyTasks:TaskChat(item, index) used to navigate to taskchat")
    this.props.navigation.navigate("TaskChat", { id: taskid, action: "maintask", sno: msgCount });
  }

  render() {
    const { item } = this.props;

    let button;
    if (item.completeStatus === "pending") {

      button =
        <View style={{ flexDirection: 'row', justifyContent: 'flex-end', alignItems: 'center' }}>

          <TouchableOpacity style={{ padding: 5, backgroundColor: '#76C54E', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.ModifyStory()}>
            <Text style={{ color: 'white', fontSize: 10 }}>MODIFY</Text>
          </TouchableOpacity>
          <TouchableOpacity style={{ padding: 5, backgroundColor: '#3DD896', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.AddSprint()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Add to Sprint</Text>
          </TouchableOpacity>
          <TouchableOpacity style={{ padding: 5, backgroundColor: '#F4A896', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.AddEpic()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Add to Epic</Text>
          </TouchableOpacity>


        </View>



    } else {

      button = null;

    }

    let buttonD;
    if (item.activeStatus === "1" && item.completeStatus === 'pending' && item.backlogs === '1') {

      buttonD =
        <View style={{ flexDirection: 'row', alignItems: 'center', marginTop: 5 }}>
          {/* <TouchableOpacity style={{ padding: 5, backgroundColor: '#630436', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.TaskAdd()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Add Task</Text>
          </TouchableOpacity> */}
          <TouchableOpacity style={{ padding: 5, backgroundColor: '#855723', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.ChangeStatus()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Change Status</Text>
          </TouchableOpacity>
          {/* <TouchableOpacity style={{ padding: 5, backgroundColor: '#203B5A', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.ViewTask()}>
            <Text style={{ color: 'white', fontSize: 10 }}>View Tasks</Text>
          </TouchableOpacity> */}


        </View>



    } else {

      buttonD = null;

    }


    let buttonA;
    if (item.completeStatus === 'pending') {

      buttonA =
        <View style={{ flexDirection: 'row', alignItems: 'center', marginTop: 5 }}>
          <TouchableOpacity style={{ padding: 5, backgroundColor: '#630436', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.TaskAdd()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Add Task</Text>
          </TouchableOpacity>

          <TouchableOpacity style={{ padding: 5, backgroundColor: '#203B5A', marginLeft: 8, borderRadius: 10 }} onPress={() => this.props.ViewTask()}>
            <Text style={{ color: 'white', fontSize: 10 }}>View Tasks</Text>
          </TouchableOpacity>


        </View>



    } else {

      buttonA = null;

    }
    let button1;
    if (item.completeStatus === "completed") {

      button1 =
        <View style={{ flexDirection: 'row', justifyContent: 'flex-end', alignItems: 'center' }}>

          <TouchableOpacity style={{ padding: 5, backgroundColor: 'orange', marginLeft: 10, borderRadius: 10 }} onPress={() => this.props.ReassignStory()}>
            <Text style={{ color: 'white', fontSize: 10 }}>Reassign</Text>
          </TouchableOpacity>
        </View>



    } else {

      button1 = null;

    }


    //  // var data1=this.state.dataSource1;
    //  const getMessagesCount = (data, msg, task, empId) => {
    //   //  console.warn("ids"+JSON.stringify(data1) +id)

    //   //  var msg=this.state.dataSource1;
    //   // console.warn("Datasource and id send by"+JSON.stringify(data1.sendBy))
    //   // let msgCount = data1.filter(message => message.sendBy === id).map((messages, i) => {
    //     let msgCount = msg.filter(message => message.readBy.split(",").indexOf(empId) === -1 && message.messagedBy !== empId && message.groupId === task.taskid).map((messages, i) => {

    //     return i

    //   })

    //   // console.warn("iiiiiiii" + msgCount)

    //   return (
    //     // console.warn("iiiiiiii" + msgCount),
    //     <View>
    //       <Text style={{ color: 'green' }}> {msgCount.length > 0 ? msgCount.length : null} </Text>
    //       {/* {msgCount.length > 0 ? msgCount.length : null} */}
    //       {
    //         msgCount.length > 0 ?

    //           <Icon name="comments" style={{ color: '#808080', paddingRight: 5 }} size={25} onPress={() => { this.props.TaskChat() }} />

    //           :
    //           <Icon name="comments" style={{ color: '#808080', paddingRight: 5 }} size={25} onPress={() => { this.props.TaskChat() }} />


    //       }

    //     </View>
    //   )

    // }


    // var data1=this.state.dataSource1;
    const getMessagesCount = (id, msg, empId) => {
      //  console.warn("ids"+JSON.stringify(data1) +id)

      //  var msg=this.state.dataSource1;
      // console.warn("Datasource and id send by"+JSON.stringify(data1.sendBy))
      // let msgCount = data1.filter(message => message.sendBy === id).map((messages, i) => {
      let msgCount = msg.filter(message => message.readBy.split(",").indexOf(empId) === -1 && message.messagedBy !== empId && message.groupId === id).map((messages, i) => {

        return i, messages

      })

      // console.warn("iiiiiiii" + id)
      // console.warn("msgcount" + msgCount)

      return (
        // console.warn("iiiiiiii" + msgCount),
        <View>
          <Text style={{ color: 'green', paddingTop: -20, marginRight: 10 }}> {msgCount.length > 0 ? msgCount.length : null} </Text>
          {/* {msgCount.length > 0 ? msgCount.length : null} */}
          {
            msgCount.length > 0 ?

              <TouchableOpacity style={{ marginTop: -20, marginLeft: 10 }} onPress={() => { this.TaskChat(id, "maintask", msgCount) }}>
                <Image style={{ width: 25, height: 25 }} source={require('../Images/chat.png')} />
              </TouchableOpacity>
              :
              <TouchableOpacity style={{ marginTop: -20, marginLeft: 10 }} onPress={() => { this.TaskChat(id, "maintask", msgCount) }}>
                <Image style={{ width: 25, height: 25, }} source={require('../Images/chat.png')} />

              </TouchableOpacity>

          }

        </View>
      )

    }




    return (

      <View>

        {/* <Collapse style={[item.cDate >= item.targetDate ? styles.container : styles.container1]}>

          <CollapseHeader style={styles.boxheader}> */}
        {/* <View style={[item.targettime <= item.cDate ? styles.container : styles.container1]}> */}
        <View style={[(item.currenttime > item.targettime && item.completeStatus === 'pending' && item.targettime !== '0000-00-00') ? styles.c : styles.c1]}>
          <View style={styles.boxheader}>
            <TouchableOpacity activeOpacity={0.8} onPress={this.changeLayout} >
              {/* <CollapseHeader style={[item.timeLeft<0?styles.boxheader:styles.boxheader1]} > */}


              <View style={{ flexDirection: 'row' }}>
                <View style={{ flexDirection: 'row', width: wp('25%') }}>
                  {/* <Text style={styles.signUpText0} >Id:</Text> */}
                  <Text style={styles.signUpText0} >{(this.props.cropcode).substring(0, 3).toUpperCase()}:</Text>

                  {/* <Text style={styles.signUpText1} >  {item.id} {item.moduleId}</Text> */}
                  <Text style={styles.signUpText1} > {item.userstory_id.substring(0, 5).toUpperCase()} {item.moduleId}</Text>
                </View>
                <View style={{ alignItems: 'flex-end', width: '70%' }}>
                  <Text >{item.assigntto}</Text>
                </View>
                {/* <Text style={styles.signUpText02} >{item.completeStatus}  </Text> */}
                <View>


                </View>

              </View>


              <View style={styles.box1}>
                <View style={{ flexDirection: 'row', width: wp('86%') }}>
                {item.completeStatus === 'pending' ?
                  <Text style={styles.signUpText00} >User Story Name:</Text>
                  :<Text style={styles.signUpText00m} >User Story Name:</Text>
        }
             {item.completeStatus === 'pending' ?
                    <Text style={{ fontSize: 13, color: '#000000', width: '55%',paddingLeft: 10, }} >{item.tasktitle}</Text>
                    : <Text style={{ fontSize: 13, color: '#000000', width: '55%', textDecorationLine: 'line-through',paddingLeft: 10, }} >{item.tasktitle}</Text>
                  }

                
                </View>
                {getMessagesCount(item.id, this.state.dataSource2, this.props.empId)}

                
              </View>



            </TouchableOpacity>
          </View>
          {/* </CollapseHeader> */}
          <View style={{ height: this.state.expanded ? null : 0, overflow: 'hidden' }}>

            <CollapseBody>

            <View style={styles.box12}>
                {button}
                {button1}
                <View style={{ backgroundColor: '#6DAE8C', marginLeft: 10, width: 25, height: 25, textAlign: 'center', justifyContent: 'center' }}>
                  <Text style={{ color: 'white', paddingLeft: 8, fontSize: 10 }}>{item.storyPoints}</Text>
                </View>
                <View style={{ backgroundColor: 'teal', marginLeft: 10, width: 35, height: 25, textAlign: 'center', justifyContent: 'center' }}>
                  <Text style={{ color: 'white', paddingLeft: 8, fontSize: 10 }}>P:{item.priorityLevel}</Text>
                </View>
               

              </View>
              <View style={{ flexDirection: 'row',marginBottom:10 }}>
                {buttonA}

                {buttonD}
              </View>
              <View style={{ flexDirection: 'row', paddingRight: 25, width: wp('75%') }}>
                <Text style={styles.signUpText44} >Description:</Text>
                <Text style={styles.signUpText33} >{item.taskdescription}</Text>
              </View>
              <View style={{ flexDirection: 'row', paddingRight: 25, width: wp('68%') }}>
                <Text style={styles.signUpText44} >Acceptance Criteria : </Text>
                <Text style={styles.signUpText33} >{item.acceptanceCriteria}</Text>
              </View>
              <View style={styles.box1}>
                <View style={{ flexDirection: 'row', width: wp('80%') }}>
                  <Text style={styles.signUpText000} >Assigned On:</Text>
                  <Text style={styles.signUpText111} >{moment(item.assignedon).format('MM.DD.YYYY')}</Text>
                </View>
                {/* <Text style={styles.signUpText002} >{TASKSTATUS}:{item.taskStatus}%Completed</Text> */}
              </View>
              <View style={{ flexDirection: 'row', paddingRight: 25, width: wp('80%') }}>
                <Text style={styles.signUpText44} >Story Progress:</Text>
                <Text style={styles.signUpText33} >{item.taskStatus}%Completed</Text>
              </View>
              {/* <View style={styles.box1}>
                <View style={{ flexDirection: 'row' }}>
                  <Text style={styles.signUpText000} >{ASSIGNEDON} :</Text>
                  <Text style={styles.signUpText1101} >{item.createdon}</Text>
                </View>
              </View> */}
              <View style={{ flexDirection: 'row', paddingRight: 25, width: wp('80%') }}>
                <Text style={styles.signUpText44} >{ASSIGNED_BY} :</Text>
                <Text style={styles.signUpText33} >{item.assignby}</Text>
              </View>
              {/* <View style={{ flexDirection: 'row', paddingRight: 25, width: wp('80%') }}>
                <Text style={styles.signUpText44} >{ASSIGNED_BY} :</Text>
                <Text style={styles.signUpText33} >{item.assignby}</Text>
              </View> */}

              {/* <View style={{ flexDirection: 'row', paddingRight: 25, }}>
                <Text style={styles.signUpText44} >Story Points:</Text>
                <Text style={styles.signUpText33} >{item.storyPoints}</Text>
              </View> */}
              <View style={styles.box1}>
                {/* <View style={{ flexDirection: 'row', width: wp('45%') }}>
                  <Text style={styles.signUpText000} >Target Time:</Text>
                  <Text style={styles.signUpText1101} >{item.targettime}</Text>
                </View> */}
                {/* <View style={{ flexDirection: 'row', width: wp('45%'), paddingLeft: 4 }}>
                  <Text style={styles.signUpText000} >{UPDATEDON}:</Text>
                  <Text style={styles.signUpText1101} >{item.taskEndDate}</Text>
                </View> */}
              </View>


            </CollapseBody>
          </View>
        </View>
        {/* </Collapse> */}
        {/* <View style={{ backgroundColor: '#C0C0C0', height: 2 }}> */}
        {/* </View> */}
      </View>
    )
  }
}

export default class UserBacklogPending extends Component {
  static navigationOptions = () => {
    return {
      tabBarOnPress({ navigation, defaultHandler }) {
        navigation.state.params.onTabFocus();
        defaultHandler();
        this.onRefresh();
      }
    };
  }

  constructor(props) {
    super(props);
    props.navigation.setParams({
      onTabFocus: this.handleTabFocus
    });
    this.state = {
      isLoading: true,
      dataSource: [],
      isFetching: false,
      open: false,
      ProjectTitle: "",
      ProjectDescription: "",
      role: '',
      userToken: '',
      getInvolved: [],
      unassignedTasks: [],
      currentsprint: [],
      manageTasks: [],
      resource: [],
      pendingTasks: [],
      backlogs: [],
      error1: '', error2: '',
      itemPressedDisabled: false,
    };
    this.unassignedTasksData();

    AsyncStorage.getItem("cropcode", (err, res) => {
      this.setState({ squadName: res });
      // console.warn("squadname" + this.state.squadName);
    });
    this.arrayholder = [];

  }
  handleTabFocus = () => {
    this.onRefresh();
  };


  componentDidMount() {
    AsyncStorage.getItem("cropcode", (err, res) => {
      this.setState({ cropcode: res });
      console.warn(this.state.cropcode);
    });
    log("Debug", "admin request projects screen is loaded");
    // this.ideas();
    this.getRequestedIdeas();
    this.GetStatus();
    // this.getModules();
    this.getActiveSprints();//active sprint user stories
    // this.getSprints();
    // this.getUnactiveSprintTasks();
    this.getUnassigned();//Backlogs user stories
    this.getModules();
    this.getSprints1();
    this.getUnactiveSprintTasks();
    this.getPending();
    this.unassignedTasksData();

    AsyncStorage.getItem("userToken", (err, res) => {
      this.setState({ empId: res });

      // console.warn(this.state.empId);
    });

  }


  //For store Agile projects for offline Start
  addAgileProjects(data) {
    // console.warn("hello naveen" + JSON.stringify(data));
    db.addAgileProjects(data).then((result) => {
      console.log(result);
    }).catch((err) => {
      console.log(err);
    })
  }
  //For store Agile projects for offline End
  //For Getting offline Project List Start
  getAgileProjects() {
    db.getAgileProjects().then((data) => {
      // console.warn("AgileProjectsList" + JSON.stringify(data))
      this.setState({
        data2: data,
      });
    }).catch((err) => {
    })
  }
  //For Getting offline Project List End

  //For store Sprints or offline Start
  addOfflineSprints(sprints, projectName) {
    db.addSprints(sprints, projectName).then((result) => {
      console.log(result);
    }).catch((err) => {
      console.log(err);
    })
  }
  //For store Sprints for offline End
  //For Getting offline Sprints List Start
  getOfflineSprints() {
    AsyncStorage.getItem("cropcode", (err, res) => {
      const projectName = res;
      db.getSprints(projectName).then((data) => {
        console.warn("SprintsList" + JSON.stringify(data))
        this.setState({
          resource: data,
        });
      }).catch((err) => {
      })
    });
  }
  //For Getting offline Sprints List End
  //For Getting offline Active Sprints List Start
  getOfflineActiveSprints(backlogsStatus) {
    AsyncStorage.getItem("cropcode", (err, res) => {
      const projectName = res;
      db.getActiveSprint(projectName).then((data) => {
        console.warn("Active Sprint" + JSON.stringify(data[0].key))
        this.setState({
          moduleId: data[0].key,
          moduleDesc: data[0].label
        })
        this.getAssignedBacklogs(backlogsStatus, data[0].key)
      }).catch((err) => {
        this.setState({
          currentsprint: [],
          moduleId: '0',
          moduleDesc: '',
          isLoading: false,
        });
      })
    });
  }
  //For Getting offline Active Sprints List End
  //For Getting Current or Feature Sprint Backlogs from offline
  getAssignedBacklogs(backlogsStatus, sprintId) {
    AsyncStorage.getItem("cropcode", (err, res) => {
      const projectName = res;
      db.getAssignedBacklogs(backlogsStatus, projectName, sprintId).then((data) => {
        console.warn(data)
        this.setState({
          currentsprint: data,
          isLoading: false,
        });
        this.arrayholder = data;
      }).catch((err) => {
        console.log(err);
        this.setState = {
          isLoading: false
        }
      })
    })
  }
  //For Getting Current or Feature Sprint Backlogs from offline

  //For Getting Current Sprint and  Unassigned Backlogs from offline
  getBacklogs(backlogsStatus) {
    AsyncStorage.getItem("cropcode", (err, res) => {
      const projectName = res;
      db.getBacklogs(backlogsStatus, projectName).then((data) => {
        if (backlogsStatus === "currentsprint") {
          this.setState({
            currentsprint: data,
            isLoading: false,
          });
        } else {
          this.setState({
            unassignedTasks: data,
            isLoading: false,
          });
        }
        this.arrayholder = data;
      }).catch((err) => {
        console.log(err);
        this.setState = {
          isLoading: false
        }
      })
    })
  }
  //For Getting Current Sprint and  Unassigned Backlogs from offline

  //For store Current Sprint and  Unassigned Backlogs from offline
  addBacklogs(backlogs, backlogStatus, projectName, sprintId) {
    // console.warn("hello" + JSON.stringify(backlogs));
    db.addBacklogs(backlogs, backlogStatus, projectName, sprintId).then((result) => {
      this.setState({
        isLoading: false,
      });
    }).catch((err) => {
      console.log(err);
      this.setState({
        isLoading: false,
      });
    })
  }

  componentWillReceiveProps(nextProps) {
    NetInfo.fetch().then(state => {
      if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
        console.log(state.type);
        Snackbar.show({
          title: 'No Internet Connection',
          backgroundColor: 'red',
          duration: Snackbar.LENGTH_LONG,
        });
        // this.getPendingtasksList(); //For pending subtaskslist from offline
      } else {
        //to get the user pending my task list
        // this.getActiveSprints();
        // this.getUnassigned();
        this.ideas();
        this.getRequestedIdeas();
        this.GetStatus();
        this.getModules();
        this.getActiveSprints();
        this.getSprints1();
        this.getUnactiveSprintTasks();
        this.getUnassigned();
        this.getPending();
        this.unassignedTasksData();
      }
    });

  }

  //get modules data
  getModules() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
            } else {

              fetch(API + 'getModules.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  userType: emp_role,
                  empId: empId,

                  action: "getModules",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // console.warn("getmodules data" + JSON.stringify(responseJson.data));
                  if (responseJson.status == 'True') {
                    this.setState({
                      isLoading: false,
                      dataSource1: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });

                  } else {
                    log("Warn", "status of employee is not available");
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });

  }


  //get ActiveSprints data
  getActiveSprints() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
              this.getOfflineActiveSprints("currentsprint")//Getting Current Sprint Backlogs in offline
              // this.getBacklogs("currentsprint") //Getting Current Sprint Backlogs in offline
            } else {

              fetch(API + 'getUpdateSprint.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  // userType: emp_role,
                  // empId: empId,

                  action: "get_sprints",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // alert(JSON.stringify(responseJson.data))
                  // console.warn("getActiveSprint data" + JSON.stringify(responseJson.data));
                  if (responseJson.status == 'True') {
                    this.setState({
                      isLoading: false,
                      dataSource1: [...responseJson.data],
                      moduleId: responseJson.data[0].moduleId,
                      moduleDesc: responseJson.data[0].moduleDesc
                    }, function () {
                      // In this block you can do something with new state.
                    });
                    AsyncStorage.setItem('moduleId', responseJson.data[0].moduleId);

                    this.getInvolvedEmployees(responseJson.data[0].moduleId)
                    this.getRequestedIdeas(responseJson.data[0].moduleId)

                  } else {
                    //For No Active Sprints
                    this.setState({
                      isLoading: false,
                      dataSource1: [],
                      moduleId: '',
                      moduleDesc: ''
                    })
                    log("Warn", "status of employee is not available");
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });

  }


  //get getInvolvedEmployees data
  getInvolvedEmployees(moduleId) {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
            } else {

              fetch(API + 'getModules.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  moduleId: moduleId,
                  // userType: emp_role,
                  // empId: empId,

                  action: "getInvolvedEmployees",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // console.warn("getActiveSprint data" + JSON.stringify(responseJson.data));
                  if (responseJson.status == 'True') {
                    this.setState({
                      isLoading: false,
                      getInvolved: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });

                  } else {
                    log("Warn", "status of employee is not available");
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });

  }



  //get Sprints data
  getSprints() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
            } else {

              fetch(API + 'getModules.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  userType: emp_role,
                  empId: empId,

                  action: "getModules",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // console.warn("get Sprints data" + JSON.stringify(responseJson.data));
                  if (responseJson.status == 'True') {
                    this.setState({
                      isLoading: false,
                      dataSource1: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });

                  } else {
                    log("Warn", "status of employee is not available");
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });

  }

  //get pending data
  getPending() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          AsyncStorage.getItem("projectId", (err, res) => {
            const projectId = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
            } else {

              fetch(API + 'backlogspage.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  userType: emp_role,
                  empId: empId,

                  action: "pending",
                  projectId:projectId,


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  if (responseJson.status == 'true') {
                    // alert("Pending Tasks" + JSON.stringify(responseJson.data))

                    console.warn("Pending Tasks" + JSON.stringify(responseJson.data));
                    this.setState({
                      isLoading: false,
                      pendingTasks: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });
                    this.arrayholder = responseJson.data;

                  } else {
                    this.arrayholder = [];
                    log("Warn", "status of employee is not available");
                    this.setState({
                      isLoading: false,
                      pendingTasks: []
                    })
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });
  });

  }


  //get UnactiveSprintTasks data
  getUnactiveSprintTasks() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
            } else {

              fetch(API + 'getManageMaintasks.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  crop: cropcode,
                  userType: emp_role,
                  empId: empId,

                  action: "getUnactiveSprintTasks",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // console.warn("getUnactiveSprintTasks data" + JSON.stringify(responseJson.data));
                  if (responseJson.status == 'True') {
                    this.setState({
                      isLoading: false,
                      dataSource1: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });

                  } else {
                    log("Warn", "status of employee is not available");
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });

  }


  //get Unassigned data
  getUnassigned() {
    // alert("Testing")
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("empId", (err, res) => {
      const empId = res;
      AsyncStorage.getItem("cropcode", (err, res) => {
        const cropcode = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;

      AsyncStorage.getItem("projectId", (err, res) => {
        const projectId = res;
          NetInfo.fetch().then(state => {
            if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
              // console.log(state.type);
              Snackbar.show({
                title: 'No Internet Connection',
                backgroundColor: 'red',
                duration: Snackbar.LENGTH_LONG,
              });
              this.getBacklogs("unassigned") //For Getting Unassigned Backlogs in offline 
            } else {

              fetch(API + 'backlogspage.php', {
                method: 'POST',
                headers: {
                  Accept: 'application/json',
                  'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                  corp: cropcode,
                  projectId:projectId
                  //   userType: emp_role,
                  //   empId: empId,

                  //     action: "getUnactiveSprintTasks",


                })
              })
                .then((response) => response.json())
                .then((responseJson) => {
                  // alert("Unassigned Tasks" + JSON.stringify(responseJson.data))
                  if (responseJson.status == 'true') {

                    console.warn("Unassigned Tasks" + JSON.stringify(responseJson.data));
                    this.addBacklogs(responseJson.data, "unassigned", cropcode, '0')//For offline store of Unassigned Backlogs
                    this.setState({
                      isLoading: false,
                      unassignedTasks: [...responseJson.data],
                    }, function () {
                      // In this block you can do something with new state.
                    });
                    this.arrayholder = responseJson.data;

                  } else {
                    this.arrayholder = [];
                    log("Warn", "status of employee is not available");
                    this.setState({
                      isLoading: false,
                      unassignedTasks: []
                    })
                  }
                })
                .catch((error) => {
                  console.error(error);
                  log("Error", "error in  getting status of employee");
                });
            }
          });
        });
      });
    });
    });

  }



  //get project list dropdown data
  GetStatus() {
    log("Info", "UserProfile:GetStatus() method is used to get status of employee");
    AsyncStorage.getItem("userName", (err, res) => {
      const userName = res;
      NetInfo.fetch().then(state => {
        if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
          // console.log(state.type);
          Snackbar.show({
            title: 'No Internet Connection',
            backgroundColor: 'red',
            duration: Snackbar.LENGTH_LONG,
          });
          this.getAgileProjects()//For Getting Project List in Offline
        } else {

          fetch(API + 'squadsList.php', {
            method: 'POST',
            headers: {
              Accept: 'application/json',
              'Content-Type': 'application/json',
            },
            body: JSON.stringify({

              username: userName,


            })
          })
            .then((response) => response.json())
            .then((responseJson) => {
              // console.warn(responseJson)
              if (responseJson.status == 'True') {
                // this.setState({
                //     isLoading: false,
                //     dataSource1: [...responseJson.data],
                // }, function () {
                //     // In this block you can do something with new state.
                // });
                this.addAgileProjects(responseJson.data) //Project list store in offline
                console.log("Testing" + JSON.stringify(responseJson.data))
                const data2 = [];

                responseJson.data.map(x => {
                  data2.push({ label: x.value, value: x.value })
                })
                this.setState({
                  data2: data2,
                })
                // console.warn("Hello" + JSON.stringify(data2))

                // this.setState({
                //     data2: responseJson.data
                // });
                // console.warn(this.state.data2);
              } else {
                log("Warn", "status of employee is not available");
              }
            })
            .catch((error) => {
              console.error(error);
              log("Error", "error in  getting status of employee");
            });
        }
      });
    });

  }

  // Update Status of Employee
  UpdateStatus(squadName) {
    // const { squadName } = this.state;
    log("Info", "UserProfile:UpdateStatus(status) method is used to update status of employee");
    // console.warn("project" + JSON.stringify(squadName));

    AsyncStorage.getItem("userName", (err, res) => {
      const userName = res;
      console.log(res);



      // console.log(cropcode);
      NetInfo.fetch().then(state => {
        if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
          console.log(state.type);
          Snackbar.show({
            title: 'No Internet Connection',
            backgroundColor: 'red',
            duration: Snackbar.LENGTH_LONG,
          });
          //for offline project switching start
          this.setState({
            squadName: squadName
          });
          AsyncStorage.setItem('cropcode', squadName);
          this.getOfflineSprints()//Getting the List of offline Sprints
          this.getOfflineActiveSprints("currentsprint") //Getting Current Sprint Backlogs in offline
          this.getBacklogs("unassigned") //For Getting Unassigned Backlogs in offline 
          //for offline project switching end
        } else {

          fetch(API + 'squadLogin.php', {
            method: 'POST',
            headers: {
              Accept: 'application/json',
              'Content-Type': 'application/json',
            },
            body: JSON.stringify({
              username: userName,
              crop: squadName,

            })
          })
            .then((response) => response.json())
            .then((responseJson) => {
              // console.warn(JSON.stringify(responseJson))

              if (responseJson.status == 'TRUE') {
                AsyncStorage.setItem('auth', responseJson.jwt) //store the token information  with exp
                const tokenDetails = jwt_decode(responseJson.jwt);
                console.log(tokenDetails.data)
                AsyncStorage.setItem('roleCount', tokenDetails.data.roleCount)
                // dispatch(setCurrentUser(tokenDetails.data)); //store the user information
                AsyncStorage.setItem('status', tokenDetails.data.empStatus)


                AsyncStorage.setItem('userToken', tokenDetails.data.empId);
                AsyncStorage.setItem('userName', tokenDetails.data.userName);
                AsyncStorage.setItem('emp_role', tokenDetails.data.role);
                AsyncStorage.setItem('cropcode', tokenDetails.data.corp);
                this.onRefresh();

                // this.props.navigation.navigate('UserProfile');
                // console.warn("HI" + empstatus)
                this.setState({

                  squadName: tokenDetails.data.corp,

                });
                //  alert("Project Changed Successfully")
                this.getRequestedIdeas();

              } else {
                //    alert("user already exist");
                log("Warn", "status of employee is not able to update");
              }

            })
            .catch((error) => {
              console.warn(error);
              log("Error", "error in updating status of employee");
            });
        }
      });
    });

  }


  componentWillReceiveProps(nextProps) {
    NetInfo.fetch().then(state => {
      if (state.type == "none" || state.type == 'unknown' || state.type == 'undefined') {
        console.log(state.type);
        Snackbar.show({
          title: 'No Internet Connection',
          backgroundColor: 'red',
          duration: Snackbar.LENGTH_LONG,
        });
        this.getRequestedIdeas(); //For pending subtaskslist from offline
        // this.onRefresh();
      } else {
        //to get the user pending my task list
        this.getRequestedIdeas();
        this.unassignedTasksData();
        // this.onRefresh();
      }
    });

  }
  //get the IdeasList or projects
  async ideas() {

    await AsyncStorage.getItem("emp_role", (err, res) => {
      console.log(res);
      this.setState({ role: res });
    });

    await AsyncStorage.getItem("userToken", (err, res) => {
      console.log(res);
      this.setState({ userToken: res });
    });
    await AsyncStorage.getItem("cropcode", (err, res) => {
      console.log(res);
      this.setState({ cropcode: res });
    });
    this.unassignedTasksData();
    this.getRequestedIdeas(this.state.role, this.state.userToken, this.state.cropcode);
  }

  // //Navigates to TaskChat Screen
  // TaskChat(item, index) {
  //   log("Info", "UserPendingMyTasks:TaskChat(item, index) used to navigate to taskchat")
  //   this.props.navigation.navigate("TaskChat", { taskid: item.taskid, action: "maintask" });
  // }
  //Refresh the data
  onRefresh() {
    // this.setState({
    //   dataSource:[],
    // })
    this.setState({

    })
    // this.getUnassigned();
    this.getRequestedIdeas();
    // this.ideas();
    // this.getRequestedIdeas();
    this.GetStatus();
    // this.getModules();
    this.getActiveSprints();
    this.getSprints1();
    this.getUnactiveSprintTasks();
    this.getUnassigned();
    this.getPending();
    this.unassignedTasksData();
    // this.getMessages();
    // this.currentsprint();

    // this.getRequestedIdeas(this.state.role, this.state.userToken, this.state.cropcode);
  }
  // componentWillReceiveProps(nextProps) {
  //   this.getRequestedIdeas();
  // }
  //getting the Requested projects List
  getRequestedIdeas() {
    AsyncStorage.getItem("cropcode", (err, res) => {
      const cropcode = res;
      AsyncStorage.getItem("userToken", (err, res) => {
        const empId = res;
        AsyncStorage.getItem("emp_role", (err, res) => {
          const emp_role = res;
          AsyncStorage.getItem("moduleId", (err, res) => {
            const moduleId = res;
            
            // console.warn(cropcode)
            log("Info", " getRequestedIdeas(role, userToken, cropcode) is used to get all requested projects at admin side");
            NetInfo.fetch().then(state => {
              if (state.type == "none") {
                console.log(state.type);
                log("Warn", "No internet connection");
                Snackbar.show({
                  title: 'No Internet Connection',
                  backgroundColor: 'red',
                  duration: Snackbar.LENGTH_LONG,
                });
                this.getAssignedBacklogs("currentsprint", moduleId) //Getting Current Sprint Backlogs in offline
              } else {
                // fetch('http://71.40.116.146:2005/getSubtasks.php',
                // fetch('http://71.40.116.146:2005/getManageMaintasks.php',
                fetch(API + 'backlogspage.php', {

                  method: 'POST',
                  headers: {
                    Accept: 'application/json',
                    'Content-Type': 'application/json',
                  },
                  body: JSON.stringify({
                    corp: cropcode,
                    empId: empId,
                    action: "currentsprint",
                    sprintId: moduleId,

                    // empId: userToken,
                    userType: emp_role
                  })
                })
                  .then((response) => response.json())
                  .then((responseJson) => {
                    // alert("currentSprints" + JSON.stringify(responseJson.data))
                    console.warn("currentSprints" + JSON.stringify(responseJson.data))
                    if (responseJson.status == 'true') {
                      // console.log(responseJson)
                      this.addBacklogs(responseJson.data, "currentsprint", cropcode, moduleId) //For offline store of currentSprint Backlogs
                      this.setState({
                        isLoading: false,
                        currentsprint: responseJson.data,
                        isFetching: false
                      }, function () {

                      });
                      this.arrayholder = responseJson.data;
                      this.unassignedTasksData();
                    }
                    else {
                      this.arrayholder = [];
                      log("Warn", "no subtasks found");
                      this.setState({
                        isLoading: false,
                        currentsprint: []
                      })
                      this.unassignedTasksData();
                      Snackbar.show({

                        title: 'No Backlogs Found',

                        backgroundColor: '#3BB9FF',
                        duration: Snackbar.LENGTH_LONG,
                      });

                    }

                  })
                  .catch((error) => {
                    console.error(error);
                    log("Error", " subtasks error");
                  });
              }
            });
          });
        });
      });
    });
  }
  //getting the Requested projects List end


  //getting the sprint list for addind maintask
  getSprints1() {
    log("Info", " getEmployees(cropcode) is used for getting the Employees list for addind maintask");
    const { ModuleId } = this.state;
    const { ideaid } = this.state;

    AsyncStorage.getItem("cropcode", (err, res) => {
      const cropcode = res;
      NetInfo.fetch().then(state => {
        if (state.type == "none") {
          console.log(state.type);
          log("Warn", "No internet connection");
          Snackbar.show({
            title: 'No Internet Connection',
            backgroundColor: 'red',
            duration: Snackbar.LENGTH_LONG,
          });
          this.getOfflineSprints(); //Getting Offline Sprint List
        } else {
          fetch(API + 'getUpdateSprint.php',
            {
              method: 'POST',
              headers: {
                Accept: 'application/json',
                'Content-Type': 'application/json',
              },
              body: JSON.stringify({
                crop: cropcode,
                action: "get_sprints"
              })
            })
            .then((response) => response.json())
            .then((responseJson) => {
              if (responseJson.status === 'True') {
                // console.warn("Sprints from active sprint board" + JSON.stringify(responseJson))
                // alert(JSON.stringify(responseJson))
                var sprintDetails = [];

                responseJson.data.map((sprints) => {
                  const [year, month, date] = sprints.startDate.split('-');
                  const [year1, month1, date1] = sprints.targetDate.split('-');
                  return (
                    sprintDetails.push({ 'key': sprints.moduleId, 'epicId': sprints.ideaId, 'label': sprints.moduleDesc })
                  );
                })

                this.setState({
                  resource: sprintDetails
                });
                this.addOfflineSprints(sprintDetails, cropcode)//Store Sprint List in Offline
              }
            })
            .catch((error) => {
              console.error(error);
              log("Error", "requested projects error");
            });
        }
      });
    });
  }



  componentWillUnmount() {
    this.setState({
      text: "",
    })
  }

  //Method for Unassigned task to set
  unassignedTasksData() {
    console.warn("pending" + JSON.stringify(this.state.pendingTasks))
    // alert("pending" + JSON.stringify(this.state.pendingTasks))

    console.warn("unassignedTasks testing" + JSON.stringify(this.state.unassignedTasks))
    const backlogs = this.state.pendingTasks.concat(this.state.unassignedTasks)

    this.setState({
      backlogs: backlogs,
     
    })
    this.arrayholder=backlogs,
    // this.onRefresh();
    // alert(JSON.stringify(backlogs))
    console.warn("manageTasks" + JSON.stringify(backlogs))
  }

  // componentWillUpdate() {
  //   console.warn("pending" + JSON.stringify(this.state.pendingTasks))
  //   console.warn("unassignedTasks testing" + JSON.stringify(this.state.unassignedTasks))
  //   const backlogs = this.state.pendingTasks.concat(this.state.unassignedTasks)

  //   this.setState({
  //     backlogs:backlogs,
  //   })
  //   // alert(JSON.stringify(backlogs))
  //   console.warn("manageTasks" + JSON.stringify(backlogs))
  //   // console.log("update..........")
  // }

  //Navigate to Project Modify Screen
  ModifyStory(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ModifyStory() method is used to move Add Module to Add ModifyUserStory screen");
    this.props.navigation.navigate('ModifyUserStory', { action: 'modify', assigntto: item.assigntto, assignedto: item.assignedTo, projectitle: item.projectitle, ideaid: item.ideano, moduleId: item.moduleId, taskid:  item.userstory_id,  tasktitle: item.tasktitle, taskdescription: item.taskdescription, acceptanceCriteria: item.acceptanceCriteria, storyPoints: item.storyPoints, priorityLevel: item.priorityLevel });

  }
  //Navigate to Project Modify Screen
  ReassignStory(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ReassignStory() method is used to move Add Module to Add ModifyUserStory screen");
    this.props.navigation.navigate('ModifyUserStory', { action: 'reassign', assigntto: item.assigntto, assignedto: item.assignedTo, projectitle: item.projectitle, ideaid: item.ideano, moduleId: item.moduleId, taskid:  item.userstory_id,  tasktitle: item.tasktitle, taskdescription: item.taskdescription, acceptanceCriteria: item.acceptanceCriteria, storyPoints: item.storyPoints, priorityLevel: item.priorityLevel });

  }
  //Navigate to Add Epic Screen
  AddEpic(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "AddEpic() method is used to move Add Module to Add AddEpic screen");
    this.props.navigation.navigate('AddEpic', { taskid:  item.userstory_id, });

  }

  //Navigate to Task Add Screen
  TaskAdd(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ChangeStatus() method is used to move Add Module to Add TaskAdd screen");
    this.props.navigation.navigate('TaskAdd', { taskid: item.userstory_id, moduleId:item.userstoryModuleId, tasktitle: item.tasktitle, sprintDate: item.targetDate,assignedTo:item.assignedTo });

  }

  //Navigate to ViewTask  Screen
  ViewTask(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ChangeStatus() method is used to move ViewTask screen");
    this.props.navigation.navigate('ViewTask', { taskId:  item.userstory_id,tasktitle: item.tasktitle, sprintDate: item.targetDate });

  }


  //Navigate to Change Status Screen
  ChangeStatus(item, index) {
    console.log(item);
    console.log(index);
    log("Info", "ChangeStatus() method is used to move Add Module to Add AddEpic screen");
    this.props.navigation.navigate('ChangeStatus', {  sprintDesc:item.moduletitle,taskid: item.userstory_id, tasktitle: item.tasktitle });

  }
  // AddSprint1(){
  //   if(assignedTo==="Null" || assignedTo==='')
  //   {
  //     alert("Select User")
  //   }
  //   else
  //   {
  //     this.AddSprint()
  //   }
  // }
  //Navigate to Add Sprint Screen
  AddSprint(item, index) {
    console.log(item);
    console.log(index);
    if(item.assigntto===null || item.assigntto==='')
    {
      alert("User Story is not assigned for any user, Please select user")
    }
    else{
    log("Info", "UserModifyProject() method is used to move Add Module to Add Sprint screen");
    this.props.navigation.navigate('AddSprint', { sprintDesc:item.moduletitle,taskid:  item.userstory_id,assign_to:item.assignedTo,title:item.tasktitle });
    }
  }
  //list seperator
  FlatListItemSeparator = () => {
    return (
      <View
        style={{
          //  height: .5,
          width: "100%",
          backgroundColor: "#000",
        }}
      />
    );
  }
  //List data for Empty
  _listEmptyComponent = () => {
    return (
      <View style={{ width: '90%', height: '80%' }}>
        <Text></Text>
      </View>
    )
  }



 //Searh based on task id ,name,description,and user
 SearchFilterFunction(text) {
  log("Info", "SearchFilterFunction(text) method  used for searching");
  console.log(text);

  const newData = this.arrayholder.filter(function (item) {
    const userstory_id = item.userstory_id.toUpperCase()
    const userstory_id1 = text.toUpperCase()
    // const moduleId = item.moduleId.toUpperCase()
    // const moduleId1 = text.toUpperCase()
    const completeStatus = item.completeStatus.toUpperCase()
    const completeStatus1 = text.toUpperCase()
    const tasktitle = item.tasktitle.toUpperCase()
    const tasktitle1 = text.toUpperCase()
    const acceptanceCriteria = item.acceptanceCriteria.toUpperCase()
    const acceptanceCriteria1 = text.toUpperCase()
    // const targettime = item.targettime.toUpperCase()
    // const targettime1 = text.toUpperCase()
    const assigntto = item.assigntto.toUpperCase()
    const assigntto1 = text.toUpperCase()
    const assignby = item.assignby.toUpperCase()
    const assignby1 = text.toUpperCase()



    return userstory_id.indexOf(userstory_id1) > -1 ||
      // moduleId.indexOf(moduleId1) > -1 ||
      completeStatus.indexOf(completeStatus1) > -1 ||
      acceptanceCriteria.indexOf(acceptanceCriteria1) > -1 ||
      // targettime.indexOf(targettime1) > -1 ||
      assigntto.indexOf(assigntto1) > -1 ||
      assignby.indexOf(assignby1) > -1 ||

      tasktitle.indexOf(tasktitle1) > -1

  })
  this.setState({
    backlogs: newData,
    text: text
  })
}
//Search data end

  render() {
    if (this.state.isLoading) {
      return (
        <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
          <DotIndicator color='#00A2C1' />
        </View>
      );

    }



    // const manageTasks = backlogs;
    return (
      <Container style={{ height: Dimensions.get('window').height }}>
        <NavigationEvents
          onDidFocus={() => this.onRefresh()}
        />



        <Item>
          <NavigationEvents
            onDidFocus={() => this.onRefresh()}
          />
          <Input placeholder="Search"
            onChangeText={(text) => this.SearchFilterFunction(text)} />
          <Icon size={25} style={{ marginLeft: 10 }} name="search" />
        </Item>
        <View style={styles.MainContainer}>
          <Toast ref="toast" />
          <View style={{ height: '90%' }}>
            {/* <Text style={{ fontSize: 18, color: 'blue', paddingLeft: 5 }}>Active Sprint</Text> */}
            <FlatList
              extraData={this.state}
              keyExtractor={this._keyExtractor}
              renderItem={this._renderItem}
              data={this.state.backlogs}
              onRefresh={() => this.onRefresh()}
              refreshing={this.state.isFetching}
              ItemSeparatorComponent={this.FlatListItemSeparator}
              renderItem={({ item, index }) =>
                <View>
                  <ListItem navigation={this.props.navigation}
                    item={item}
                    empId={this.state.empId}
                    cropcode={this.state.cropcode}
                    ModifyStory={() => this.ModifyStory(item, index)}//For Modify Sprint
                    ReassignStory={() => this.ReassignStory(item, index)}//For Reassign Sprint 
                    AddEpic={() => this.AddEpic(item, index)}//For Adding Epic
                    AddSprint={() => this.AddSprint(item, index)}//For Adding Sprint
                    TaskChat={() => this.TaskChat(item, index)}//For TaskLevel Chat
                    ChangeStatus={() => this.ChangeStatus(item, index)}//Change Status
                    TaskAdd={() => this.TaskAdd(item, index)}//Task Add
                    ViewTask={() => this.ViewTask(item, index)}//View Task

                  />
                </View>
              }
              keyExtractor={item => item.id}
              ListEmptyComponent={this._listEmptyComponent}
            />
          </View>
          {/* <Text style={{fontSize:25}}>Backlog</Text> */}

          {/* <View style={{ height: '90%' }}>
            <FlatList
              extraData={this.state}
              keyExtractor={this._keyExtractor}
              renderItem={this._renderItem}
              data={this.state.unassignedTasks}
              onRefresh={() => this.onRefresh()}
              refreshing={this.state.isFetching}
              ItemSeparatorComponent={this.FlatListItemSeparator}
              renderItem={({ item, index }) =>
                <View>
                  <ListItem navigation={this.props.navigation}
                    item={item}
                    // AdminProjectInfo={() => this.AdminProjectInfo(item, index)}
                    TaskChat={() => this.TaskChat(item, index)}//For TaskLevel Chat

                  />
                </View>
              }
              keyExtractor={item => item.id}
              ListEmptyComponent={this._listEmptyComponent}
            />
          </View> */}


          <TouchableOpacity onPress={() => this.props.navigation.navigate("AddStory", {moduleid: this.state.moduleId, IdeaId: this.state.ideano })} style={styles.bottomView}>
            <View style={styles.bottomView} >
              <Text style={styles.textStyle}>{ADDMAINTASK}</Text>
            </View>
          </TouchableOpacity>
        </View>


      </Container>
    );
  }
}

const styles = StyleSheet.create({
  MainContainer:
  {
    flex: 1,
    width: Dimensions.get('window').width,
    height: Dimensions.get('window').height,
  },
  c: {
    backgroundColor: '#f58484',
    marginTop: 10,
    paddingRight: 20,
    margin: "2%",
    borderWidth: 0.8,
    borderColor: 'grey',
    width: '96%',
    borderRadius: 10
  },
  c1: {
    backgroundColor: '#DCDCDC',
    marginTop: 10,
    paddingRight: 20,
    margin: "2%",
    borderWidth: 0.8,
    borderColor: 'grey',
    width: '96%',
    borderRadius: 10
  },
  buttonContainer: {
    width: wp('100%'),
    alignSelf: 'baseline',
    color: '#d2691e',
    backgroundColor: '#fadbd8',
    marginLeft: wp('2%'),
    marginRight: wp('2%'),
  },
  signupButton: {
  },
  subcontainer: {
    flex: 2,
    flexDirection: 'row',
  },
  signUpText0: {
    fontSize: 14,
    color: 'green',
    paddingLeft: 10,
    //fontWeight: "bold",
  },
  signUpText1: {
    fontSize: 14,
    color: 'green',
    // fontWeight: "bold",
  },

  signUpText00: {
    fontSize: 13,
    color: '#323233',
    paddingLeft: 10,

  },
  signUpText00m: {
    fontSize: 13,
    color: '#323233',
    paddingLeft: 10,
    textDecorationLine: 'line-through',

  },
  signUpText11: {
    fontSize: 13,
    // paddingBottom: 10,
    color: '#000000',
    //fontWeight: "bold",
    width: wp('55%')

  },
  signUpText000: {
    fontSize: 12,
    color: 'black',
    paddingLeft: 10,
  },
  signUpText111: {
    fontSize: 12,
    // paddingBottom: 10,

    color: 'black',

    paddingLeft: -20,
    width: '60%'
  },
  signUpText1101: {
    fontSize: 12,
    // paddingBottom: 10,

    color: 'black',

    paddingLeft: -20,
    width: '70%'
  },
  end: {
    alignItems: 'flex-end',
  },
  end1: {
    flex: 1,
    justifyContent: 'space-between',
    flexDirection: 'row',
  },
  s: {
    justifyContent: 'center',

    backgroundColor: '#ed7070',
    shadowOffset: { width: 50, height: 50 },
    alignItems: 'center',
    width: wp('40%'),
    height: hp('12%'),
    borderTopLeftRadius: 10,
    borderBottomLeftRadius: 10,

  },
  signUpText2: {
    fontSize: 13,
    paddingRight: 10,
    paddingLeft: 13,
    color: 'black',
    justifyContent: 'center',

  },

  bottomView: {
    flex: 1,
    ...Platform.select({
      ios: {
        flexDirection: 'row',
        justifyContent: 'center',
        position: 'absolute',
        height: FOOTER_MAX_HEIGHT,
        bottom: 0,
        left: 0,
        right: 0,
        backgroundColor: 'black',
        alignItems: 'center'
      },
      android: {
        flexDirection: 'row',
        justifyContent: 'center',
        position: 'absolute',
        height: FOOTER_MAX_HEIGHT,
        bottom: 0,
        left: 0,
        right: 0,
        backgroundColor: 'black',
        alignItems: 'center'
      },
    }),
  },


  textStyle: {
    color: '#fff',
    fontSize: 18,
    backgroundColor: '#00a2c1',
    paddingLeft: 10,
    paddingRight: 10,
    // paddingBottom: 5,
    paddingTop: 5,
    borderRadius: 5,
  },

  signUpText02: {
    fontSize: 13,
    paddingRight: 5,
    color: 'green',
    paddingLeft: 13,

    // paddingBottom: 10,
    // fontWeight: 'bold',
  },
  signUpText022: {
    fontSize: 13,
    paddingLeft: 13,
    color: 'green',
    // paddingBottom: 10,
    justifyContent: 'center',

  },
  signUpText002: {
    fontSize: 13,
    paddingLeft: 12,
    // paddingBottom: 10,
    color: 'black'

  },
  signUpText0002: {
    fontSize: 13,
    paddingRight: 45,
    // paddingTop: 20,
    paddingLeft: 13,
    // color: 'red',
    // paddingBottom: 10,
    // fontWeight: 'bold',
    justifyContent: 'center',

  },
  signUpText3: {

    // paddingBottom: 10,
    // paddingLeft: 10,
    fontSize: 13,
    // paddingRight:hp('-10%'),
    paddingRight: 13,
    width: '70%',
    // fontWeight: "bold",
    alignItems: 'center',
    color: '#000000'
  },
  signUpText4: {
    // paddingBottom: 10,
    paddingLeft: 10,
    // fontWeight: 'bold',
    color: '#323233',
    fontSize: 13,
    alignItems: 'center',
  },


  signUpText33: {

    // paddingBottom: 10,
    // paddingLeft: 13,
    fontSize: 13,
    // paddingRight:hp('-10%'),
    paddingRight: 35,
    // fontWeight: 'bold',
    // paddingTop: -10,
    alignItems: 'center',
    // width: wp('80%'),
    color: 'black'

  },
  signUpText44: {
    paddingLeft: 10,
    fontSize: 13,
    alignItems: 'center',
    color: 'black'
  },

  signup: {
    //paddingTop:20,
    color: "#FFF",
  },
  boxone: {
    flex: 1,
    marginTop: 5,

  },
  boxtwo: {
    flex: 1,

  },
  boxthree: {
    flex: 1,

  },
  box: {
    justifyContent: 'space-between',
    flexDirection: 'row',
    position: 'relative',
    // marginBottom: 10,

  },
  box12: {
    marginTop:10,
    justifyContent: 'space-between',
    flexDirection: 'row',
    position: 'relative',
    paddingRight: 25,
  },
  box1: {
    paddingTop: 10,
    justifyContent: 'space-between',
    flexDirection: 'row',
    position: 'relative',
    paddingRight: 25,
  },
  signUpText: {
    fontSize: 20,
    justifyContent: 'center',


    color: 'white',
    alignSelf: 'center',
  },
  boxheader: {
    //  backgroundColor:'green',
    justifyContent: 'space-between',
    flexDirection: 'column',
    position: 'relative',
    marginBottom: 15,

  },
  opencancel: {
    flex: 1,
    ...Platform.select({
      ios: {
        backgroundColor: 'red', margin: 20, height: 30, alignItems:
          "center", justifyContent: 'center'
      },
      android: {
        backgroundColor: 'red', margin: 20, height: 30, alignItems:
          "center", justifyContent: 'center'
      },
    }),
  },
  opensave: {
    flex: 1,
    ...Platform.select({
      ios: {
        backgroundColor: 'green', margin: 20, height: 30, alignItems:
          "center", justifyContent: 'center'
      },
      android: {
        backgroundColor: 'green', margin: 20, height: 30, alignItems:
          "center", justifyContent: 'center'
      },
    }),
  },

});